package cmd

import (
	"github.com/carapace-sh/carapace"
	"github.com/carapace-sh/carapace-bin/pkg/actions/tools/kubectl"
	"github.com/spf13/cobra"
)

var create_serviceaccountCmd = &cobra.Command{
	Use:     "serviceaccount NAME [--dry-run=server|client|none]",
	Short:   "Create a service account with the specified name",
	Aliases: []string{"sa"},
	Run:     func(cmd *cobra.Command, args []string) {},
}

func init() {
	carapace.Gen(create_serviceaccountCmd).Standalone()

	create_serviceaccountCmd.Flags().Bool("allow-missing-template-keys", false, "If true, ignore any errors in templates when a field or map key is missing in the template. Only applies to golang and jsonpath output formats.")
	create_serviceaccountCmd.Flags().String("dry-run", "", "Must be \"none\", \"server\", or \"client\". If client strategy, only print the object that would be sent, without sending it. If server strategy, submit server-side request without persisting the resource.")
	create_serviceaccountCmd.Flags().String("field-manager", "", "Name of the manager used to track field ownership.")
	create_serviceaccountCmd.Flags().StringP("output", "o", "", "Output format. One of: (json, yaml, name, go-template, go-template-file, template, templatefile, jsonpath, jsonpath-as-json, jsonpath-file).")
	create_serviceaccountCmd.Flags().Bool("save-config", false, "If true, the configuration of current object will be saved in its annotation. Otherwise, the annotation will be unchanged. This flag is useful when you want to perform kubectl apply on this object in the future.")
	create_serviceaccountCmd.Flags().Bool("show-managed-fields", false, "If true, keep the managedFields when printing objects in JSON or YAML format.")
	create_serviceaccountCmd.Flags().String("template", "", "Template string or path to template file to use when -o=go-template, -o=go-template-file. The template format is golang templates [http://golang.org/pkg/text/template/#pkg-overview].")
	create_serviceaccountCmd.Flags().String("validate", "", "Validation mode.")
	create_serviceaccountCmd.Flag("dry-run").NoOptDefVal = " "
	create_serviceaccountCmd.Flag("validate").NoOptDefVal = " "
	createCmd.AddCommand(create_serviceaccountCmd)

	carapace.Gen(create_serviceaccountCmd).FlagCompletion(carapace.ActionMap{
		"dry-run":  kubectl.ActionDryRunModes(),
		"output":   kubectl.ActionOutputFormats(),
		"template": carapace.ActionFiles(),
		"validate": kubectl.ActionValidationModes(),
	})
}
